matminer.datasets package — matminer 0.4.2 documentation

# matminer.datasets package

## Subpackages

- matminer.datasets.test_datasets package
  - Submodules
  - matminer.datasets.test_datasets.test_datasets module
  - Module contents

## Submodules

## matminer.datasets.dataframe_loader module

`matminer.datasets.dataframe_loader.` `load_dielectric_constant`(include_metadata=False)
  References:
    Petousis, I., Mrdjenovich, D., Ballouz, E., Liu, M., Winston, D., Chen, W., Graf, T., Schladt, T. D., Persson, K. A. & Prinz, F. B. High-throughput screening of inorganic compounds for the discovery of novel dielectric and optical materials. Sci. Data 4, 160134 (2017).
  Args:
    include_metadata (bool): whether to return cif, meta, poscar

  Returns (pd.DataFrame)

`matminer.datasets.dataframe_loader.` `load_elastic_tensor`(include_metadata=False)
  References:
    Jong, M. De, Chen, W., Angsten, T., Jain, A., Notestine, R., Gamst, A., Sluiter, M., Ande, C. K., Zwaag, S. Van Der, Plata, J. J., Toher, C., Curtarolo, S., Ceder, G., Persson, K. and Asta, M., “Charting the complete elastic properties of inorganic crystalline compounds”, Scientific Data volume 2, Article number: 150009 (2015)
  Args:
    include_metadata (bool): whether to return cif, kpoint_density, poscar

  Returns (pd.DataFrame)

`matminer.datasets.dataframe_loader.` `load_flla`()
  References:

    1) F. Faber, A. Lindmaa, O.A. von Lilienfeld, R. Armiento, “Crystal structure representations for machine learning models of formation energies”, Int. J. Quantum Chem. 115 (2015) 1094–1101. doi:10.1002/qua.24917.

    2) (raw data) Jain, A., Ong, S. P., Hautier, G., Chen, W., Richards, W. D., Dacek, S., Cholia, S., Gunter, D., Skinner, D., Ceder, G. & Persson, K. A. Commentary: The Materials Project: A materials genome approach to accelerating materials innovation. APL Mater. 1, 11002 (2013).

  Returns (pd.DataFrame)

`matminer.datasets.dataframe_loader.` `load_piezoelectric_tensor`(include_metadata=False)
  References:
    de Jong, M., Chen, W., Geerlings, H., Asta, M. & Persson, K. A. A database to enable discovery and design of piezoelectric materials. Sci. Data 2, 150053 (2015)
  Args:
    include_metadata (bool): whether to return cif, meta, poscar

  Returns (pd.DataFrame)

## Module contents